import { FromHttpOptions } from "@aws-sdk/credential-provider-http";
import { RemoteProviderInit } from "@smithy/credential-provider-imds";
import { AwsCredentialIdentityProvider } from "@smithy/types";
export declare const ENV_IMDS_DISABLED = "AWS_EC2_METADATA_DISABLED";
export declare const remoteProvider: (
  init: RemoteProviderInit | FromHttpOptions
) => Promise<AwsCredentialIdentityProvider>;
